from __future__ import unicode_literals

from mopidy import config, ext

__version__ = '0.1.1'


class Extension(ext.Extension):

    dist_name = 'Mopidy-Mobile'
    ext_name = 'mobile'
    version = __version__

    def get_default_config(self):
        from os import path
        conf_file = path.join(path.dirname(__file__), 'ext.conf')
        return config.read(conf_file)

    def get_config_schema(self):
        schema = super(Extension, self).get_config_schema()
        schema['title'] = config.String()
        return schema

    def setup(self, registry):
        from .app import factory
        registry.add('http:app', {'name': 'mobile', 'factory': factory})



from __future__ import unicode_literals

import logging
import os

import tornado.web

WWW_DIR = os.path.join(os.path.dirname(__file__), 'www')

logger = logging.getLogger(__name__)


class IndexHandler(tornado.web.RequestHandler):

    def initialize(self, config):
        from . import Extension
        self._template_kwargs = {
            'title': config[Extension.ext_name]['title']
        }

    def get(self, path):
        return self.render('index.html', **self._template_kwargs)

    def get_template_path(self):
        return WWW_DIR


def factory(config, core):
    logger.info('Mopidy-Mobile static directory is %s', WWW_DIR)
    return [
        (r'/', tornado.web.RedirectHandler, {'url': 'index.html'}),
        (r'/(index.html)', IndexHandler, {'config': config}),
        (r'/(.*)', tornado.web.StaticFileHandler, {'path': WWW_DIR})
    ]
